@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Create network transition chord progressions
 
-our $VERSION = '0.0603';
+our $VERSION = '0.0604';
 
 use Carp qw(croak);
 use Data::Dumper::Compact qw(ddc);
@@ -332,17 +332,23 @@ Music::Chord::Progression - Create network transition chord progressions
 
 =head1 VERSION
 
-version 0.0603
+version 0.0604
 
 =head1 SYNOPSIS
 
   use Music::Chord::Progression;
+  use MIDI::Util qw(setup_score midi_format);
 
   my $prog = Music::Chord::Progression->new;
 
-  my $chords = $prog->generate; # LoL with "max" number of bars
+  my $chord_type = $prog->substitution('m'); # m7 or mM7
 
-  my $chord_type = $prog->substitution('m'); # returns m7 or mM7
+  my $progression = $prog->generate;
+
+  my $score = setup_score();
+  for my $chord (@$progression) {
+      $score->n('wn', midi_format(@$chord));
+  }
 
 =head1 DESCRIPTION
 
@@ -364,6 +370,15 @@ Default: C<8>
 
 The network transitions between chords of the progression.
 
+The keys must start with C<1> and be contiguous to the end.
+
+Ending on C<12> keys all the notes of the chromatic scale.  Ending on
+C<7> represents diatonic notes, given the B<scale_name>.
+
+If you do not wish a scale note to be chosen, include it among the
+keys, but do not refer to it and do not give it any neighbors.  Thus,
+in the first example, the 7th degree of the scale will never be chosen.
+
 Default:
 
   { 1 => [qw( 1 2 3 4 5 6 )],
@@ -390,15 +405,6 @@ A contrived chromatic example where each note connects to every note:
     12 => [1 .. 12],
   }
 
-The keys must start with C<1> and be contiguous to the end.
-
-Ending on C<12> keys all the notes of the chromatic scale.  Ending on
-C<7> represents diatonic notes, given the B<scale_name>.
-
-If you do not wish a scale note to be chosen, include it among the
-keys, but do not refer to it and do not give it any neighbors.  Thus,
-in the first example, the 7th degree of the scale will never be chosen.
-
 =head2 chord_map
 
 The chord names of each scale position.
@@ -445,7 +451,7 @@ Default: C<4>
 
 =head2 tonic
 
-Whether to start the progression with the tonic chord or not.
+Set the start of the progression.
 
 If this is given as C<1> the tonic chord starts the progression.  If
 given as C<0> a neighbor of the tonic is chosen.  If given as C<-1> a
@@ -455,7 +461,7 @@ Default: C<1>
 
 =head2 resolve
 
-Whether to end the progression with the tonic chord or not.
+Set the end the progression.
 
 If this is given as C<1> the tonic chord ends the progression.  If
 given as C<0> a neighbor of the last chord is chosen.  If given as
@@ -527,6 +533,7 @@ Show the progress and chosen values.
     octave     => 5,
     tonic      => 0,
     resolve    => -1,
+    flat       => 1,
     substitute => 1,
     verbose    => 1,
   );
